# 0.5.3
    - Adding link to ripser++ GPU version by Simon Zhang

# 0.5.2:
    - Cocycle indices now correspond to point cloud indices, even
      when a greedy permutation is in use

# 0.4.1:
    - Fixed packing so C++ is MSVC compatible.

# 0.4.0:
    - Added license to distributed packages.

# 0.3.2:
    - Added support for greedy permutations.
    - Outsourced plotting to persim.
    - Outsourced data construction in examples to tadasets.
    - Revamped documentation.

# 0.3.0:
    - Completed JOSS review, thanks @lmcinnes and @arokem!!
    - Documentation details updated.

# 0.2.7:
    - Updating home url

# 0.2.6:
    - Update license to MIT.

# 0.2.5:
    - Docs and notebooks revamp.
    - Support for Windows.

# 0.2.4:
    - Interface redesign

# 0.2.3:
    - Support for lower star filtrations
    - Notebook on lower star filtrations

# 0.2.1:
    - Sparse distance matrix support
    - Two additional notebooks about sparsity
    - Language agnostic bindings support
    - Bug fixes (filtrations with low number of points)

# 0.2.0:
    - Bug fixes (int rounding error for small magnitude threshold)

# 0.1.7:
    - Generation of cocycles.
    - Handle inf in C code and in plotting.
    - Many new options for plotting diagrams.
